@@ -1,6 +1,6 @@
 # _*_ coding: utf-8 _*_
 #
-# hspylib-firebase v0.9.64
+# hspylib-firebase v0.9.66
 #
 # Package: main.firebase
 """Package initialization."""
@@ -9,6 +9,7 @@ __all__ = [
   '__classpath__', 
   '__main__', 
   'core', 
-  'entity'
+  'entity', 
+  'exception'
 ]
-__version__ = '0.9.64'
+__version__ = '0.9.66'
